==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/RangeAllocationListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RangeAllocationListFluent<A extends RangeAllocationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,RangeAllocation item);
  public A setToItems(Integer index,RangeAllocation item);
  public A addToItems(io.fabric8.openshift.api.model.RangeAllocation... items);
  public A addAllToItems(Collection<RangeAllocation> items);
  public A removeFromItems(io.fabric8.openshift.api.model.RangeAllocation... items);
  public A removeAllFromItems(Collection<RangeAllocation> items);
  public A removeMatchingFromItems(Predicate<RangeAllocationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RangeAllocation> getItems();
  public List<RangeAllocation> buildItems();
  public RangeAllocation buildItem(Integer index);
  public RangeAllocation buildFirstItem();
  public RangeAllocation buildLastItem();
  public RangeAllocation buildMatchingItem(Predicate<RangeAllocationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<RangeAllocationBuilder> predicate);
  public A withItems(List<RangeAllocation> items);
  public A withItems(io.fabric8.openshift.api.model.RangeAllocation... items);
  public Boolean hasItems();
  public RangeAllocationListFluent.ItemsNested<A> addNewItem();
  public RangeAllocationListFluent.ItemsNested<A> addNewItemLike(RangeAllocation item);
  public RangeAllocationListFluent.ItemsNested<A> setNewItemLike(Integer index,RangeAllocation item);
  public RangeAllocationListFluent.ItemsNested<A> editItem(Integer index);
  public RangeAllocationListFluent.ItemsNested<A> editFirstItem();
  public RangeAllocationListFluent.ItemsNested<A> editLastItem();
  public RangeAllocationListFluent.ItemsNested<A> editMatchingItem(Predicate<RangeAllocationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,RangeAllocationFluent<RangeAllocationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/RangeAllocationListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RangeAllocationListFluent<A extends RangeAllocationListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,RangeAllocation item);
  public A setToItems(int index,RangeAllocation item);
  public A addToItems(io.fabric8.openshift.api.model.RangeAllocation... items);
  public A addAllToItems(Collection<RangeAllocation> items);
  public A removeFromItems(io.fabric8.openshift.api.model.RangeAllocation... items);
  public A removeAllFromItems(Collection<RangeAllocation> items);
  public A removeMatchingFromItems(Predicate<RangeAllocationBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<RangeAllocation> getItems();
  public List<RangeAllocation> buildItems();
  public RangeAllocation buildItem(int index);
  public RangeAllocation buildFirstItem();
  public RangeAllocation buildLastItem();
  public RangeAllocation buildMatchingItem(Predicate<RangeAllocationBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<RangeAllocationBuilder> predicate);
  public A withItems(List<RangeAllocation> items);
  public A withItems(io.fabric8.openshift.api.model.RangeAllocation... items);
  public Boolean hasItems();
  public RangeAllocationListFluent.ItemsNested<A> addNewItem();
  public RangeAllocationListFluent.ItemsNested<A> addNewItemLike(RangeAllocation item);
  public RangeAllocationListFluent.ItemsNested<A> setNewItemLike(int index,RangeAllocation item);
  public RangeAllocationListFluent.ItemsNested<A> editItem(int index);
  public RangeAllocationListFluent.ItemsNested<A> editFirstItem();
  public RangeAllocationListFluent.ItemsNested<A> editLastItem();
  public RangeAllocationListFluent.ItemsNested<A> editMatchingItem(Predicate<RangeAllocationBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,RangeAllocationFluent<RangeAllocationListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
